PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/linalg.h Source File

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

linalg.h
Go to the documentation of this file.
1
5 #ifndef FFT_H
6 #define FFT_H
7 #include <mkl.h>
8 #include <mkl_types.h>
9
13 void trilinear_interpolate_values(double complex* x, double* frac, int* fftg, double complex* values);
14
18 double complex* fft_calloc(int num_items, int item_size);
19
26 void fft3d(double complex* x, int* G_bounds, double* lattice,
27 double* kpt, int* Gs, float complex* Cs, int num_waves, int* fftg);
28
29 #endif
pawpyseed.core.quadrature.x
list x
Definition: quadrature.py:9
fft_calloc
double complex * fft_calloc(int num_items, int item_size)
fft3d
void fft3d(double complex *x, int *G_bounds, double *lattice, double *kpt, int *Gs, float complex *Cs, int num_waves, int *fftg)
trilinear_interpolate_values
void trilinear_interpolate_values(double complex *x, double *frac, int *fftg, double complex *values)